==> core-react-0.8.0.tgz: package/es/Spinner/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';
import omit from '../_utils/omit';
import IndicatorSVG from './IndicatorSVG';
 // Render indicator

var defaultIndicator = null;

function shouldDelay(isLoading, delay) {
  return !!isLoading && !!delay && !Number.isNaN(Number(delay));
}

function renderIndicator(_props) {
  var indicator = _props.indicator,
      size = _props.size;
  var sizeMap = {
    sm: 36,
    md: 60,
    lg: 96
  };
  var dotClassName = "".concat("waui", "-spinner__spinner-element-indictor");

  if (React.isValidElement(indicator)) {
    return React.createElement("div", {
      className: dotClassName
    }, indicator);
  }

  if (React.isValidElement(defaultIndicator)) {
    return React.cloneElement(defaultIndicator, {
      className: cx(defaultIndicator.props.className, dotClassName)
    });
  }

  return React.createElement("div", {
    className: cx(dotClassName, "".concat("waui", "-spinner__spinner-element-indictor-svg"))
  }, React.createElement(IndicatorSVG, {
    width: sizeMap[size],
    height: sizeMap[size]
  }));
}

var Spinner = /*#__PURE__*/function (_React$Component) {
  _inherits(Spinner, _React$Component);

  _createClass(Spinner, null, [{
    key: "setDefaultIndicator",
    value: function setDefaultIndicator(indicator) {
      defaultIndicator = indicator;
    }
  }]);

  function Spinner(props) {
    var _this;

    _classCallCheck(this, Spinner);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Spinner).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "debounceTimeout", void 0);

    _defineProperty(_assertThisInitialized(_this), "delayTimeout", void 0);

    _defineProperty(_assertThisInitialized(_this), "delayUpdateSpinning", function () {
      var isLoading = _this.props.isLoading;

      if (_this.state.isLoading !== isLoading) {
        _this.setState({
          isLoading: isLoading
        });
      }
    });

    var _isLoading = props.isLoading,
        delay = props.delay;
    _this.state = {
      isLoading: _isLoading && !shouldDelay(_isLoading, delay)
    };
    return _this;
  }

  _createClass(Spinner, [{
    key: "isNestedPattern",
    value: function isNestedPattern() {
      return !!(this.props && this.props.children);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$props = this.props,
          isLoading = _this$props.isLoading,
          delay = _this$props.delay;

      if (shouldDelay(isLoading, delay)) {
        this.delayTimeout = window.setTimeout(this.delayUpdateSpinning, delay);
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.debounceTimeout) {
        clearTimeout(this.debounceTimeout);
      }

      if (this.delayTimeout) {
        clearTimeout(this.delayTimeout);
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var _this2 = this;

      var currentSpinning = this.state.isLoading;
      var isLoading = this.props.isLoading;

      if (currentSpinning === isLoading) {
        return;
      }

      var delay = this.props.delay;

      if (this.debounceTimeout) {
        clearTimeout(this.debounceTimeout);
      }

      if (currentSpinning && !isLoading) {
        // Close spinner
        this.debounceTimeout = window.setTimeout(function () {
          return _this2.setState({
            isLoading: isLoading
          });
        }, 300);

        if (this.delayTimeout) {
          clearTimeout(this.delayTimeout);
        }
      } else {
        if (shouldDelay(isLoading, delay)) {
          if (this.delayTimeout) {
            clearTimeout(this.delayTimeout);
          }

          this.delayTimeout = window.setTimeout(this.delayUpdateSpinning, delay);
        } else {
          // Open spinner without delay
          this.setState({
            isLoading: isLoading
          });
        }
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _cx;

      var _this$props2 = this.props,
          className = _this$props2.className,
          size = _this$props2.size,
          cover = _this$props2.cover,
          tip = _this$props2.tip,
          wrapperClassName = _this$props2.wrapperClassName,
          other = _objectWithoutProperties(_this$props2, ["className", "size", "cover", "tip", "wrapperClassName"]);

      var isLoading = this.state.isLoading;
      var spinClassName = cx("".concat("waui", "-spinner__spinner-element"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_sm"), size === 'sm'), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_lg"), size === 'lg'), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_white"), cover === 'white'), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_black"), cover === 'black'), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_spinning"), isLoading), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_show-text"), !!tip), _cx), className); // fix https://fb.me/react-unknown-prop

      var divProps = omit(other, ['isLoading', 'delay', 'indicator']);
      var spinElement = React.createElement("div", {
        className: spinClassName
      }, this.isNestedPattern() && React.createElement("div", {
        className: "".concat("waui", "-spinner__spinner-element-cover")
      }), renderIndicator(this.props), tip ? React.createElement("div", {
        className: "".concat("waui", "-spinner__spinner-element-text")
      }, tip) : null);

      if (this.isNestedPattern()) {
        var animateClassName = "waui" + '-spinner_nested-loading';

        if (wrapperClassName) {
          animateClassName += ' ' + wrapperClassName;
        }

        var containerClassName = cx("".concat("waui", "-spinner__container"), _defineProperty({}, "".concat("waui", "-spinner__container_loading"), isLoading));
        return React.createElement("div", _extends({}, divProps, {
          className: animateClassName,
          style: null
        }), spinElement, React.createElement("div", {
          className: containerClassName
        }, this.props.children));
      }

      return spinElement;
    }
  }]);

  return Spinner;
}(React.Component);

Spinner.propTypes = {
  children: PropTypes.node,

  /** Spinner's own class property */
  className: PropTypes.string,

  /** The outermost class property of the Spinner wrapper */
  wrapperClassName: PropTypes.string,

  /** Whether is loading */
  isLoading: PropTypes.bool,

  /** Customize the description */
  tip: PropTypes.string,

  /** The sizes */
  size: PropTypes.oneOf(['sm', 'md', 'lg']),

  /** The style of backdrop */
  cover: PropTypes.oneOf(['white', 'black']),

  /** Loading indicator */
  indicator: PropTypes.node,

  /** The delay time of Spinner, default value is `300` */
  delay: PropTypes.number
};
Spinner.defaultProps = {
  isLoading: true,
  size: 'md',
  cover: 'white',
  wrapperClassName: ''
};
export default Spinner;

==> core-react-0.8.2.tgz: package/es/Spinner/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';
import omit from '../_utils/omit';
import IndicatorSVG from './IndicatorSVG';
 // Render indicator

var defaultIndicator = null;

function shouldDelay(isLoading, delay) {
  return !!isLoading && !!delay && !Number.isNaN(Number(delay));
}

function renderIndicator(_props) {
  var indicator = _props.indicator,
      size = _props.size;
  var sizeMap = {
    sm: 36,
    md: 60,
    lg: 96
  };
  var dotClassName = "".concat("waui", "-spinner__spinner-element-indictor");

  if (React.isValidElement(indicator)) {
    return (/*#__PURE__*/React.createElement("div", {
        className: dotClassName
      }, indicator)
    );
  }

  if (React.isValidElement(defaultIndicator)) {
    return React.cloneElement(defaultIndicator, {
      className: cx(defaultIndicator.props.className, dotClassName)
    });
  }

  return (/*#__PURE__*/React.createElement("div", {
      className: cx(dotClassName, "".concat("waui", "-spinner__spinner-element-indictor-svg"))
    }, /*#__PURE__*/React.createElement(IndicatorSVG, {
      width: sizeMap[size],
      height: sizeMap[size]
    }))
  );
}

var Spinner = /*#__PURE__*/function (_React$Component) {
  _inherits(Spinner, _React$Component);

  _createClass(Spinner, null, [{
    key: "setDefaultIndicator",
    value: function setDefaultIndicator(indicator) {
      defaultIndicator = indicator;
    }
  }]);

  function Spinner(props) {
    var _this;

    _classCallCheck(this, Spinner);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Spinner).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "debounceTimeout", void 0);

    _defineProperty(_assertThisInitialized(_this), "delayTimeout", void 0);

    _defineProperty(_assertThisInitialized(_this), "delayUpdateSpinning", function () {
      var isLoading = _this.props.isLoading;

      if (_this.state.isLoading !== isLoading) {
        _this.setState({
          isLoading: isLoading
        });
      }
    });

    var _isLoading = props.isLoading,
        delay = props.delay;
    _this.state = {
      isLoading: _isLoading && !shouldDelay(_isLoading, delay)
    };
    return _this;
  }

  _createClass(Spinner, [{
    key: "isNestedPattern",
    value: function isNestedPattern() {
      return !!(this.props && this.props.children);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$props = this.props,
          isLoading = _this$props.isLoading,
          delay = _this$props.delay;

      if (shouldDelay(isLoading, delay)) {
        this.delayTimeout = window.setTimeout(this.delayUpdateSpinning, delay);
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.debounceTimeout) {
        clearTimeout(this.debounceTimeout);
      }

      if (this.delayTimeout) {
        clearTimeout(this.delayTimeout);
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var _this2 = this;

      var currentSpinning = this.state.isLoading;
      var isLoading = this.props.isLoading;

      if (currentSpinning === isLoading) {
        return;
      }

      var delay = this.props.delay;

      if (this.debounceTimeout) {
        clearTimeout(this.debounceTimeout);
      }

      if (currentSpinning && !isLoading) {
        // Close spinner
        this.debounceTimeout = window.setTimeout(function () {
          return _this2.setState({
            isLoading: isLoading
          });
        }, 300);

        if (this.delayTimeout) {
          clearTimeout(this.delayTimeout);
        }
      } else {
        if (shouldDelay(isLoading, delay)) {
          if (this.delayTimeout) {
            clearTimeout(this.delayTimeout);
          }

          this.delayTimeout = window.setTimeout(this.delayUpdateSpinning, delay);
        } else {
          // Open spinner without delay
          this.setState({
            isLoading: isLoading
          });
        }
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _cx;

      var _this$props2 = this.props,
          className = _this$props2.className,
          size = _this$props2.size,
          cover = _this$props2.cover,
          tip = _this$props2.tip,
          wrapperClassName = _this$props2.wrapperClassName,
          other = _objectWithoutProperties(_this$props2, ["className", "size", "cover", "tip", "wrapperClassName"]);

      var isLoading = this.state.isLoading;
      var spinClassName = cx("".concat("waui", "-spinner__spinner-element"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_sm"), size === 'sm'), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_lg"), size === 'lg'), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_white"), cover === 'white'), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_black"), cover === 'black'), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_spinning"), isLoading), _defineProperty(_cx, "".concat("waui", "-spinner__spinner-element_show-text"), !!tip), _cx), className); // fix https://fb.me/react-unknown-prop

      var divProps = omit(other, ['isLoading', 'delay', 'indicator']);
      var spinElement = /*#__PURE__*/React.createElement("div", {
        className: spinClassName
      }, this.isNestedPattern() && /*#__PURE__*/React.createElement("div", {
        className: "".concat("waui", "-spinner__spinner-element-cover")
      }), renderIndicator(this.props), tip ? /*#__PURE__*/React.createElement("div", {
        className: "".concat("waui", "-spinner__spinner-element-text")
      }, tip) : null);

      if (this.isNestedPattern()) {
        var animateClassName = "waui" + '-spinner_nested-loading';

        if (wrapperClassName) {
          animateClassName += ' ' + wrapperClassName;
        }

        var containerClassName = cx("".concat("waui", "-spinner__container"), _defineProperty({}, "".concat("waui", "-spinner__container_loading"), isLoading));
        return (/*#__PURE__*/React.createElement("div", _extends({}, divProps, {
            className: animateClassName,
            style: null
          }), spinElement, /*#__PURE__*/React.createElement("div", {
            className: containerClassName
          }, this.props.children))
        );
      }

      return spinElement;
    }
  }]);

  return Spinner;
}(React.Component);

Spinner.propTypes = {
  children: PropTypes.node,

  /** Spinner's own class property */
  className: PropTypes.string,

  /** The outermost class property of the Spinner wrapper */
  wrapperClassName: PropTypes.string,

  /** Whether is loading */
  isLoading: PropTypes.bool,

  /** Customize the description */
  tip: PropTypes.string,

  /** The sizes */
  size: PropTypes.oneOf(['sm', 'md', 'lg']),

  /** The style of backdrop */
  cover: PropTypes.oneOf(['white', 'black']),

  /** Loading indicator */
  indicator: PropTypes.node,

  /** The delay time of Spinner, default value is `300` */
  delay: PropTypes.number
};
Spinner.defaultProps = {
  isLoading: true,
  size: 'md',
  cover: 'white',
  wrapperClassName: ''
};
export default Spinner;
